admin — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »

# admin

@TODO: rewrite docstring

Admin classes, specify how objects should be rendered in the gui

An admin class has class attributes like ‘list_display’ which contains the columns that should be displayed in a list view (again, see Django)

So this ‘list_display’ attribute can be overwritten in the Admin class for each model.

But for the gui generation itself, we don’t use the class attributes, but we use methods, like ‘getColumns’, that way, we can make the gui very specific, on the context

- action
  - application_action
  - base
  - form_action
  - list_action
- application_admin
- entity_admin
- not_editable_admin
- object_admin
- section
- validator
  - entity_validator
  - object_validator

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »

Comments
blog comments powered by Disqus